@@ -1,7 +1,7 @@
 package Exception::Handler;
 use strict;
 use vars qw( $VERSION );
-$VERSION = 1.00_2; # 12/23/02, 1:44 am
+$VERSION = 1.00_3; # Fri Sep 19 00:37:33 CDT 2003
 
 # --------------------------------------------------------
 # Constructor
@@ -85,7 +85,7 @@ $ialias. $sub
             : '-was called without args' ]}
        @{[ ($evaltext)
             ? '-was called to evalate text'
-            : '-was not called to evaluate anything' ]}]
+            : '-was not called to evaluate anything' ]}
 __ERR__
       }
       else {
@@ -131,32 +131,41 @@ sub DESTROY { } sub AUTOLOAD { }
 =pod
 
 =head1 NAME
+
 Exception::Handler - Report exceptions with formatted text call-stack
 
 =head1 VERSION
+
 1.00_2
 
 =head1 @EXPORT, @EXPORT_OK
+
 None.
 
 =head1 Methods
+
    new()
    fail()
    trace()
 
 =head2 AUTOLOAD-ed methods
+
 None.
 
 =head1 PREREQUISITES
+
 None.
 
 =head1 AUTHOR
+
 Tommy Butler <cpan@atrixnet.com>
 
 =head1 COPYRIGHT
+
 Copyright(c) 2001-2003, Tommy Butler.  All rights reserved.
 
 =head1 LICENSE
+
 This library is free software, you may redistribute
 and/or modify it under the same terms as Perl itself.
 
